@@ -1,4 +1,4 @@
-# Copyright (C) 2014-2017 by the Free Software Foundation, Inc.
+# Copyright (C) 2014-2018 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -72,13 +72,16 @@ RESOURCE = dict(
     include_rfc2369_headers=False,
     info='This is the mailing list info',
     moderator_password='password',
+    max_message_size='150',
     posting_pipeline='virgin',
     reply_goes_to_list='point_to_list',
     reply_to_address='bee@example.com',
+    require_explicit_destination=True,
     send_welcome_message=False,
     subject_prefix='[ant]',
     subscription_policy='confirm_then_moderate',
     welcome_message_uri='mailman:///welcome.txt',
+    respond_to_post_requests=True,
     )
 
 
