@@ -1,4 +1,4 @@
-# Copyright (C) 2012-2017 by the Free Software Foundation, Inc.
+# Copyright (C) 2012-2018 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -19,7 +19,6 @@
 
 import unittest
 
-from email import message_from_binary_file
 from mailman.app.lifecycle import create_list
 from mailman.app.moderator import hold_message
 from mailman.database.transaction import transaction
@@ -32,7 +31,6 @@ from mailman.testing.helpers import (
     call_api, get_queue_messages, set_preferred,
     specialized_message_from_string as mfs)
 from mailman.testing.layers import RESTLayer
-from pkg_resources import resource_filename
 from urllib.error import HTTPError
 from zope.component import getUtility
 
@@ -144,6 +142,25 @@ Something else.
                      dict(action='discard'))
         self.assertEqual(cm.exception.code, 404)
 
+    def test_subject_encoding_error(self):
+        # GL#383: messages with badly encoded Subject headers crash the REST
+        # server.
+        self._msg = mfs("""\
+From: anne@example.com
+To: ant@example.com
+Subject: =?GB2312?B?saa9o7fmtNPEpbVaQ2h1o6zDt7uoz+PX1L/guq7AtKGj?=
+Message-ID: <alpha>
+
+Something else.
+""")
+        with transaction():
+            held_id = hold_message(self._mlist, self._msg)
+        json, response = call_api(
+            'http://localhost:9001/3.0/lists/ant@example.com/held')
+        self.assertEqual(response.status_code, 200)
+        self.assertEqual(json['total_size'], 1)
+        self.assertEqual(json['entries'][0]['request_id'], held_id)
+
 
 class TestSubscriptionModeration(unittest.TestCase):
     layer = RESTLayer
@@ -208,24 +225,6 @@ class TestSubscriptionModeration(unittest.TestCase):
         emails = set(entry['email'] for entry in json['entries'])
         self.assertEqual(emails, {'anne@example.com', 'bart@example.com'})
 
-    def test_view_malformed_held_message(self):
-        # Opening a bad (i.e. bad structure) email and holding it.
-        email_path = resource_filename(
-            'mailman.rest.tests.data', 'bad_email.eml')
-        with open(email_path, 'rb') as fp:
-            msg = message_from_binary_file(fp)
-        msg.sender = 'aperson@example.com'
-        with transaction():
-            hold_message(self._mlist, msg)
-        # Now trying to access held messages from REST API should not give
-        # 500 server error if one of the messages can't be parsed properly.
-        json, response = call_api(
-            'http://localhost:9001/3.0/lists/ant@example.com/held')
-        self.assertEqual(response.status_code, 200)
-        self.assertEqual(len(json['entries']), 1)
-        self.assertEqual(json['entries'][0]['msg'],
-                         'This message is defective')
-
     def test_individual_request(self):
         # We can view an individual request.
         with transaction():
