@@ -1,4 +1,4 @@
-# Copyright (C) 2016-2017 by the Free Software Foundation, Inc.
+# Copyright (C) 2016-2018 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -24,7 +24,8 @@ from contextlib import ExitStack
 from datetime import timedelta
 from dns.exception import DNSException
 from dns.rdatatype import CNAME, TXT
-from dns.resolver import NXDOMAIN, NoAnswer
+from dns.resolver import NXDOMAIN, NoAnswer, NoNameservers
+from email import message_from_bytes
 from http.server import BaseHTTPRequestHandler, HTTPServer
 from lazr.config import as_timedelta
 from mailman.app.lifecycle import create_list
@@ -156,6 +157,8 @@ def get_dns_resolver(
                 raise NoAnswer
             if dparts[2] == 'info':
                 raise DNSException('no internet')
+            if dparts[2] == 'home':
+                raise NoNameservers
             if dparts[1] != 'example' or dparts[2] != 'biz':
                 raise NXDOMAIN
             self.response = Answer()
@@ -210,6 +213,21 @@ class TestDMARCRules(TestCase):
 From: anne
 To: ant@example.com
 
+""")
+        rule = dmarc.DMARCMitigation()
+        with get_dns_resolver():
+            self.assertFalse(rule.check(mlist, msg, {}))
+
+    def test_non_ascii_in_from_address(self):
+        # Non-ascii headers with message_from_bytes can return a Header
+        # objest on msg.get().
+        mlist = create_list('ant@example.com')
+        # Use action reject.  The rule only hits on reject and discard.
+        mlist.dmarc_mitigate_action = DMARCMitigateAction.reject
+        msg = message_from_bytes(b"""\
+From: Ann\xe9 <anne@example.com>
+To: ant@example.com
+
 """)
         rule = dmarc.DMARCMitigation()
         with get_dns_resolver():
@@ -227,7 +245,7 @@ To: ant@example.com
         mark = LogFileMark('mailman.error')
         rule = dmarc.DMARCMitigation()
         with get_dns_resolver():
-            self.assertFalse(rule.check(mlist, msg, {}))
+            self.assertTrue(rule.check(mlist, msg, {}))
         line = mark.readline()
         self.assertEqual(
             line[-144:],
@@ -235,6 +253,25 @@ To: ant@example.com
             'anne@example.info (_dmarc.example.info). '
             'Abstract base class shared by all dnspython exceptions.\n')
 
+    def test_dmarc_nonameservers_exception(self):
+        mlist = create_list('ant@example.com')
+        # Use action reject.  The rule only hits on reject and discard.
+        mlist.dmarc_mitigate_action = DMARCMitigateAction.reject
+        msg = mfs("""\
+From: anne@example.home
+To: ant@example.com
+
+""")
+        mark = LogFileMark('mailman.error')
+        rule = dmarc.DMARCMitigation()
+        with get_dns_resolver():
+            self.assertTrue(rule.check(mlist, msg, {}))
+        line = mark.readline()
+        self.assertEqual(
+            line[-84:],
+            'DNSException: No Nameservers available for '
+            'anne@example.home (_dmarc.example.home).\n')
+
     def test_cname_wrong_txt_name(self):
         mlist = create_list('ant@example.com')
         # Use action reject.  The rule only hits on reject and discard.
