@@ -1,4 +1,4 @@
-# Copyright (C) 2008-2017 by the Free Software Foundation, Inc.
+# Copyright (C) 2008-2018 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -151,7 +151,9 @@ class TestableMaster(Master):
             until the pass condition is set.
         :type start_check: Callable taking no arguments, returning nothing.
         """
-        super().__init__(restartable=False, config_file=config.filename)
+        super().__init__(
+            restartable=False,
+            config_file=os.environ.get('MAILMAN_CONFIG_FILE', config.filename))
         self.start_check = start_check
         self.event = threading.Event()
         self.thread = threading.Thread(target=self.loop)
@@ -345,9 +347,9 @@ class configuration:
         self._values = kws.copy()
 
     def _apply(self):
-        lines = ['[{0}]'.format(self._section)]
+        lines = ['[{}]'.format(self._section)]
         for key, value in self._values.items():
-            lines.append('{0}: {1}'.format(key, value))
+            lines.append('{}: {}'.format(key, value))
         config.push(self._uuid, NL.join(lines))
 
     def _remove(self):
@@ -355,6 +357,7 @@ class configuration:
 
     def __enter__(self):
         self._apply()
+        return self
 
     def __exit__(self, *exc_info):
         self._remove()
